[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# Company Logo client library for Python

[![API Version](https://img.shields.io/badge/api-v4.0.0-blue)](https://developer.factset.com/api-catalog/)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.CompanyLogo)](https://pypi.org/project/fds.sdk.CompanyLogo/)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

Consume FactSet collected Company Logos through an API that seamlessly integrates with company fundamentals and estimates data
(listed equities data available via the stocks API), quotes, time series, and other Digital APIs.

The logo API provides access to logos for a global universe of listed companies. The logos could be accessed by using national and
international identifiers like ISIN, CUSIP, WKN, Valor, etc. and are a nice feature for comprehensive visualizations of equities
on overview pages (factsheets).

Logo collection and maintenance takes into account IPOs, M&A notifications, and further consistency check mechanisms.

The Company Logo API seamlessly integrates with the [Stocks API](https://developer.factset.com/api-catalog/stocks-api-digital-portals)
for equities and estimates data and the [Quotes API](https://developer.factset.com/api-catalog/real-time-quotes-api), allowing
access to detailed price and performance information of listings. The [Quotes API](https://developer.factset.com/api-catalog/real-time-quotes-api)
also supports basic security identifier cross-reference (see for example /notation/crossReference/getByFactSetMarketSymbol to retrieve an instrument id).
For direct access to price histories for charting, please refer to the
[Real-Time Time Series API](https://developer.factset.com/api-catalog/real-time-time-series-api).
 


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 4.0.0
- SDK version: 0.20.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.CompanyLogo==0.20.0
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.CompanyLogo==0.20.0
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.CompanyLogo
from fds.sdk.CompanyLogo.api import company_api
from fds.sdk.CompanyLogo.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.CompanyLogo.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.CompanyLogo.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.CompanyLogo.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = company_api.CompanyApi(api_client)
    identifier = "FDS-US" # str | Identifier to resolve.
    identifier_type = "tickerRegion" # str | Type of the identifier. | Value | Description | | --- | --- | | idInstrument | MDG identifier of an instrument. | | idNotation | MDG identifier of a listing. | | fdsPermanentIdentifierSecurity | FactSet Permanent Identifier on security level. | | fdsPermanentIdentifierListing | FactSet Permanent Identifier on listing level. | | fdsPermanentIdentifierRegional | Regional FactSet Permanent Identifier. | | tickerExchange | FactSet market symbol of a listing. | | tickerRegion | Regional FactSet ticker symbol. | | sedol | SEDOL or IDII of a listing. | | isin | ISIN of an instrument. | | wkn | WKN of an instrument. | | valor | Valor number of an instrument. | | cusip | CUSIP or CINS identifier of an instrument |  
    format = "rectangular" # str | Format of the logos. | Value | Description | | --- | --- | | rectangular | Logos in rectangular format | | square | Logos in square format |   (optional) if omitted the server will use the default value of "rectangular"
    attributes = [
        "_attributes_example",
    ] # [str] | Limit the attributes returned in the response to the specified set. (optional)

    try:
        # List of URLs of company logos.
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.get_company_logo_get(identifier, identifier_type, format=format, attributes=attributes)

        pprint(api_response)
    except fds.sdk.CompanyLogo.ApiException as e:
        print("Exception when calling CompanyApi->get_company_logo_get: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # List of URLs of company logos.
    #     api_response, http_status_code, response_headers = api_instance.get_company_logo_get_with_http_info(identifier, identifier_type, format=format, attributes=attributes)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.CompanyLogo.ApiException as e:
    #     print("Exception when calling CompanyApi->get_company_logo_get: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # List of URLs of company logos.
    #     async_result = api_instance.get_company_logo_get_async(identifier, identifier_type, format=format, attributes=attributes)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.CompanyLogo.ApiException as e:
    #     print("Exception when calling CompanyApi->get_company_logo_get: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # List of URLs of company logos.
    #     async_result = api_instance.get_company_logo_get_with_http_info_async(identifier, identifier_type, format=format, attributes=attributes)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.CompanyLogo.ApiException as e:
    #     print("Exception when calling CompanyApi->get_company_logo_get: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.CompanyLogo

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.CompanyLogo.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.CompanyLogo

configuration = fds.sdk.CompanyLogo.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.CompanyLogo

configuration = fds.sdk.CompanyLogo.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.CompanyLogo

configuration = fds.sdk.CompanyLogo.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/wealth/v4*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CompanyApi* | [**get_company_logo_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/CompanyLogo/v4/docs/CompanyApi.md#get_company_logo_get) | **GET** /company/logo/get | List of URLs of company logos.


## Documentation For Models

 - [InlineResponse200](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/CompanyLogo/v4/docs/InlineResponse200.md)
 - [InlineResponse200Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/CompanyLogo/v4/docs/InlineResponse200Data.md)
 - [InlineResponse200DataLarge](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/CompanyLogo/v4/docs/InlineResponse200DataLarge.md)
 - [InlineResponse200DataMedium](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/CompanyLogo/v4/docs/InlineResponse200DataMedium.md)
 - [InlineResponse200DataSmall](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/CompanyLogo/v4/docs/InlineResponse200DataSmall.md)
 - [InlineResponse200DataVector](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/CompanyLogo/v4/docs/InlineResponse200DataVector.md)
 - [InlineResponse200Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/CompanyLogo/v4/docs/InlineResponse200Meta.md)
 - [StatusObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/CompanyLogo/v4/docs/StatusObject.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.CompanyLogo.apis and fds.sdk.CompanyLogo.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.CompanyLogo.api.default_api import DefaultApi`
- `from fds.sdk.CompanyLogo.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.CompanyLogo
from fds.sdk.CompanyLogo.apis import *
from fds.sdk.CompanyLogo.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

